package org.jeecg.modules.api.okki.account.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.api.okki.account.entity.OkkiAccount;
import org.jeecg.modules.api.okki.account.service.IOkkiAccountService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;

 /**
 * @Description: 小二账号
 * @Author: jeecg-boot
 * @Date:   2024-05-10
 * @Version: V1.0
 */
@Api(tags="小二账号")
@RestController
@RequestMapping("/account/okkiAccount")
@Slf4j
public class OkkiAccountController extends JeecgController<OkkiAccount, IOkkiAccountService> {
	@Autowired
	private IOkkiAccountService okkiAccountService;
	
	/**
	 * 分页列表查询
	 *
	 * @param okkiAccount
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "小二账号-分页列表查询")
	@ApiOperation(value="小二账号-分页列表查询", notes="小二账号-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<OkkiAccount>> queryPageList(OkkiAccount okkiAccount,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<OkkiAccount> queryWrapper = QueryGenerator.initQueryWrapper(okkiAccount, req.getParameterMap());
		Page<OkkiAccount> page = new Page<OkkiAccount>(pageNo, pageSize);
		IPage<OkkiAccount> pageList = okkiAccountService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param okkiAccount
	 * @return
	 */
	@AutoLog(value = "小二账号-添加")
	@ApiOperation(value="小二账号-添加", notes="小二账号-添加")
	@RequiresPermissions("account:okki_account:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody OkkiAccount okkiAccount) {
		okkiAccountService.save(okkiAccount);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param okkiAccount
	 * @return
	 */
	@AutoLog(value = "小二账号-编辑")
	@ApiOperation(value="小二账号-编辑", notes="小二账号-编辑")
	@RequiresPermissions("account:okki_account:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody OkkiAccount okkiAccount) {
		okkiAccountService.updateById(okkiAccount);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "小二账号-通过id删除")
	@ApiOperation(value="小二账号-通过id删除", notes="小二账号-通过id删除")
	@RequiresPermissions("account:okki_account:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		okkiAccountService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "小二账号-批量删除")
	@ApiOperation(value="小二账号-批量删除", notes="小二账号-批量删除")
	@RequiresPermissions("account:okki_account:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.okkiAccountService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "小二账号-通过id查询")
	@ApiOperation(value="小二账号-通过id查询", notes="小二账号-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<OkkiAccount> queryById(@RequestParam(name="id",required=true) String id) {
		OkkiAccount okkiAccount = okkiAccountService.getById(id);
		if(okkiAccount==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(okkiAccount);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param okkiAccount
    */
    @RequiresPermissions("account:okki_account:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, OkkiAccount okkiAccount) {
        return super.exportXls(request, okkiAccount, OkkiAccount.class, "小二账号");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("account:okki_account:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, OkkiAccount.class);
    }

}
